# Lingu

Python module for Natural Language Processing

Developed for use on the Icelandic language (íslenska)

## Documentation
Welcome to Lingu

Tokenization for Icelandic by tokenizer(pip)


## Examples
### Basic use case

*Postprocessing ocr generated text:*

```
from lingu.ocr.postprocessing import correct

text = correct(ocr_text)

```


## Copyright and License

***Copyright © 2020 Lingu ehf.***

This software is licensed under the Gnu General Public License v3 (GPLv3)